process_type, updater, and refresh_leaf parameters. Add quiet = TRUE to the list of arguments to make the function "shut up" the massive verbose text.report.xgb(data, label, folds, params, normalize = TRUE,
classification = TRUE, threshold = 0.5, importance = TRUE,
unbiased = TRUE, stats = TRUE, plots = TRUE, plot_type = "S",
output_file = "report.xgb.html", output_dir = getwd(), open_file = TRUE,
quiet = FALSE, ...)report.xgb.helper.TRUE.TRUE.classification == TRUE. Defaults to 0.5.TRUE.TRUE.TRUE, also returns the metrics and the out of fold predictions. Defaults to TRUE.TRUE."p" for points, "l" for lines, "b" for points+line, "c" for line without points, "o" for overplotted (points+line overlapping), "h" for high-density vertical lines (histogram-like), "s" for optimistic stair steps, "S" for pessimistic stair steps, "n" to plot nothing. Defaults to "S" for pessimistic stair step."report.lm.html".getwd().TRUE.FALSE.rmarkdown::render."Metrics"), the machine learning probabilities ("Probs"), the folds "Folds", the fitted values per fold ("Fitted"), the predicted values per fold ("Predicted"), the biased feature importance ("BiasedImp"), and the unbiased feature importance ("UnbiasedImp") if they were computed. Otherwise, returns TRUE.# No example.
## Not run: ------------------------------------
# library(Laurae)
# library(data.table)
# library(rmarkdown)
# library(xgboost)
# library(DT)
# library(formattable)
# library(matrixStats)
# library(lattice)
# library(R.utils)
## ---------------------------------------------
Run the code above in your browser using DataLab